@@ -44,11 +44,11 @@ L<IO::Handle|SPVM::IO::Handle>.
 
 =head2 Timeout
 
-  has Timeout : protected int;
+  has Timeout : protected double;
 
 =head2 peername
 
-  has peername : protected ro Sys::Socket::Sockaddr;
+  has peername : protected Sys::Socket::Sockaddr;
 
 See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
@@ -76,7 +76,7 @@ The socket is set to non-blocking mode.
 
 =item * Blocking : Int
 
-=item * Timeout : Int
+=item * Timeout : Double
 
 =item * Listen : Int
 
@@ -106,7 +106,7 @@ Gets the L</"Proto"> field.
 
 =head2 timeout
 
-  method timeout : int ();
+  method timeout : double ();
 
 Gets the L</"Timeout"> field.
 
@@ -114,6 +114,10 @@ Gets the L</"Timeout"> field.
 
   method new_from_instance : IO::Socket ($options : object[] = undef);
 
+=head2 peername
+
+  method peername : Sys::Socket::Sockaddr ();
+
 =head2 DESTROY
 
   method DESTROY : void ();
@@ -124,7 +128,7 @@ Gets the L</"Timeout"> field.
 
 =head2 connect
 
-  method connect : int ($address : Sys::Socket::Sockaddr);
+  method connect : void ($address : Sys::Socket::Sockaddr);
 
 See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
@@ -148,11 +152,11 @@ See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
 =head2 listen
 
-  method listen : int ($queue : int = 5);
+  method listen : void ($queue : int = 5);
 
 =head2 bind
 
-  method bind : int ($address : Sys::Socket::Sockaddr);
+  method bind : void ($address : Sys::Socket::Sockaddr);
 
 See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
@@ -164,7 +168,7 @@ See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
 =head2 shutdown
 
-  method shutdown : int ($sockfd : int, $how : int);
+  method shutdown : void ($sockfd : int, $how : int);
 
 =head2 atmark
 
@@ -174,9 +178,9 @@ See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
   method sockopt : int ($level : int, $optname : int);
 
-=head2 set_sockopt
+=head2 setsockopt
 
-  method set_sockopt : int ($level : int, $optname : int, $optval : int);
+  method setsockopt : void ($level : int, $optname : int, $optval : object of string|Int)
 
 =head2 connected
 
@@ -186,7 +190,7 @@ See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
 =head2 socket
 
-  method socket : int ($domain : int, $type : int, $protocol : int = 0);
+  method socket : void ($domain : int, $type : int, $protocol : int = 0);
 
 =head2 socketpair
 
